@@ -104,6 +104,7 @@ typedef enum zbar_symbol_type_e {
     ZBAR_CODE39      =     39,  /**< Code 39. @since 0.4 */
     ZBAR_PDF417      =     57,  /**< PDF417. @since 0.6 */
     ZBAR_QRCODE      =     64,  /**< QR Code. @since 0.10 */
+    ZBAR_SQCODE      =     80,  /**< SQ Code. @since 0.20.1 */
     ZBAR_CODE93      =     93,  /**< Code 93. @since 0.11 */
     ZBAR_CODE128     =    128,  /**< Code 128 */
 
@@ -249,7 +250,8 @@ typedef struct video_controls_s {
  * @returns 0
  */
 extern int zbar_version(unsigned *major,
-                        unsigned *minor);
+                        unsigned *minor,
+			unsigned *patch);
 
 /** set global library debug level.
  * @param verbosity desired debug level.  higher values create more spew
@@ -984,6 +986,12 @@ extern int zbar_process_one(zbar_processor_t *processor,
 extern int zbar_process_image(zbar_processor_t *processor,
                               zbar_image_t *image);
 
+/** enable dbus IPC API.
+ * @returns 0 succesful
+ */
+int zbar_processor_request_dbus(zbar_processor_t *proc,
+                                int req_dbus_enabled);
+
 /** display detail for last processor error to stderr.
  * @returns a non-zero value suitable for passing to exit()
  */
@@ -1285,6 +1293,13 @@ zbar_image_scanner_set_data_handler(zbar_image_scanner_t *scanner,
                                     const void *userdata);
 
 
+/** request sending decoded codes via D-Bus
+ * @see zbar_processor_parse_config()
+ * @since 0.21
+ */
+extern int zbar_image_scanner_request_dbus(zbar_image_scanner_t *scanner,
+                                           int req_dbus_enabled);
+
 /** set config for indicated symbology (0 for all) to specified value.
  * @returns 0 for success, non-0 for failure (config does not apply to
  * specified symbology, or value out of range)
